@@ -3,7 +3,7 @@ package WiringPi::API;
 use strict;
 use warnings;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 require XSLoader;
 XSLoader::load('WiringPi::API', $VERSION);
@@ -22,6 +22,7 @@ my @wpi_c_functions = qw(
     lcdSendCommand      lcdPosition         lcdCharDef
     lcdPutChar          lcdPuts             setInterrupt
     softPwmCreate       softPwmWrite        softPwmStop
+    sr595Setup
 );
 
 my @wpi_perl_functions = qw(
@@ -32,6 +33,7 @@ my @wpi_perl_functions = qw(
     lcd_display     lcd_cursor      lcd_cursor_blink    lcd_send_cmd
     lcd_position    lcd_char_def    lcd_put_char        lcd_puts
     set_interrupt   soft_pwm_create soft_pwm_write      soft_pwm_stop
+    shift_reg_setup
 );
 
 our @EXPORT_OK;
@@ -205,6 +207,28 @@ sub lcd_puts {
     lcdPuts($fd, $string);
 }
 
+# shift register functions
+
+sub shift_reg_setup {
+    shift if @_ == 6;
+    my ($pin_base, $num_pins, $data_pin, $clock_pin, $latch_pin) = @_;
+
+    die "\$pin_base must be an integer\n" if $pin_base !~ /^\d+$/;
+
+    if ($num_pins < 0 && $num_pins > 32){
+        die "\$num_pins must be between 0 and 32\n"     
+    }
+
+    for ($data_pin, $clock_pin, $latch_pin){
+        if ($_ < 0 && $_ > 40){
+            die "$data_pin, $clock_pin and $latch_pin must all be valid " .
+                "GPIO pin numbers\n";
+        }
+    }
+
+    sr595Setup($pin_base, $num_pins, $data_pin, $clock_pin, $latch_pin);
+}
+
 # threading functions
 
 sub thread_create {
@@ -282,6 +306,7 @@ wrapper for C<wiringPiISR()> in order to make it functional here.
     lcdSendCommand      lcdPosition         lcdCharDef
     lcdPutChar          lcdPuts             setInterrupt
     softPwmCreate       softPwmWrite        softPwmStop
+    sr595Setup
 
 Exported with the C<:perl> tag.
 
@@ -294,6 +319,7 @@ Perl wrapper functions for the XS functions.
     lcd_display     lcd_cursor      lcd_cursor_blink    lcd_send_cmd
     lcd_position    lcd_char_def    lcd_put_char        lcd_puts
     set_interrupt   soft_pwm_create soft_pwm_write      soft_pwm_stop
+    shift_reg_setup
 
 =head1 EXPORT_TAGS
 
@@ -783,6 +809,51 @@ Mandatory: The string name of a subroutine previously written in your user code
 that will be called when the interrupt is triggered. This is your interrupt
 handler.
 
+=head1 SHIFT REGISTER FUNCTIONS
+
+Shift registers allow you to add extra output pins by multiplexing a small
+number of GPIO.
+
+Currently, we support the SR74HC595 unit, which provides eight outputs by using
+only three GPIO. To further, this particular unit can be daisy chained up to
+four wide to provide an additional 32 outputs using the same three GPIO pins.
+
+=head2 shift_reg_setup
+
+This function configures the Raspberry Pi to use a shift register (The
+SR74HC595 is currently supported).
+
+Parameters:
+
+    $pin_base
+
+Mandatory: Signed integer, higher than that of all existing GPIO pins. This
+parameter registers pin 0 on the shift register to an internal GPIO pin number.
+For example, setting this to 100, you will be able to access the first output
+on the register as GPIO 100 in all other functions.
+
+    $num_pins
+
+Mandatory: Signed integer, the number of outputs on the shift register. For a
+single SR74HC595, this is eight. If you were to daisy chain two together, this
+parameter would be 16.
+
+    $data_pin
+
+Mandatory: Integer, the GPIO pin number connected to the register's C<DS> pin
+(14). Can be any GPIO pin capable of output.
+
+    $clock_pin
+
+Mandatory: Integer, the GPIO pin number connected to the register's C<SHCP> pin
+(11). Can be any GPIO pin capable of output.
+
+    $latch_pin
+
+Mandatory: Integer, the GPIO pin number connected to the register's C<STCP> pin
+(12). Can be any GPIO pin capable of output.
+
+
 head1 AUTHOR
 
 Steve Bertrand, E<lt>steveb@cpan.orgE<gt>
